import * as _zag_js_anatomy from '@zag-js/anatomy';
import { RequiredBy, PropTypes, DirectionProperty, CommonProperties, NormalizeProps } from '@zag-js/types';
import * as _zag_js_core from '@zag-js/core';
import { StateMachine } from '@zag-js/core';
import { StrokeOptions } from 'perfect-freehand';

declare const anatomy: _zag_js_anatomy.AnatomyInstance<"root" | "control" | "segment" | "segmentPath" | "separator" | "clearTrigger" | "label">;

interface Point {
    x: number;
    y: number;
    pressure: number;
}
interface DrawDetails {
    paths: string[];
}
interface DrawingOptions extends StrokeOptions {
    /**
     * The color of the stroke.
     * Note: Must be a valid CSS color string, not a css variable.
     */
    fill?: string;
}
type DataUrlType = "image/png" | "image/jpeg" | "image/svg+xml";
interface DrawEndDetails {
    paths: string[];
    getDataUrl(type: DataUrlType, quality?: number): Promise<string>;
}
interface PublicContext extends DirectionProperty, CommonProperties {
    /**
     * Callback when the signature pad is drawing.
     */
    onDraw?(details: DrawDetails): void;
    /**
     * Callback when the signature pad is done drawing.
     */
    onDrawEnd?(details: DrawEndDetails): void;
    /**
     * The drawing options.
     */
    drawing: DrawingOptions;
    /**
     * Whether the signature pad is disabled.
     */
    disabled?: boolean;
    /**
     * Whether the signature pad is read-only.
     */
    readOnly?: boolean;
}
interface PrivateContext {
    /**
     * The layers of the signature pad. A layer is a snapshot of a single stroke interaction.
     */
    paths: string[];
    /**
     * The current layer points.
     */
    currentPoints: Point[];
    /**
     * The current stroke path
     */
    currentPath: string | null;
}
type ComputedContext = Readonly<{
    isInteractive: boolean;
    isEmpty: boolean;
}>;
type UserDefinedContext = RequiredBy<PublicContext, "id">;
interface MachineContext extends PublicContext, PrivateContext, ComputedContext {
}
interface MachineState {
    value: "idle" | "drawing";
}
type State = StateMachine.State<MachineContext, MachineState>;
type Send = StateMachine.Send<StateMachine.AnyEventObject>;
interface SegmentPathProps {
    path: string;
}
interface MachineApi<T extends PropTypes = PropTypes> {
    /**
     * Whether the signature pad is empty.
     */
    isEmpty: boolean;
    /**
     * Whether the user is currently drawing.
     */
    isDrawing: boolean;
    /**
     * The current path being drawn.
     */
    currentPath: string | null;
    /**
     * The paths of the signature pad.
     */
    paths: string[];
    /**
     * Returns the data URL of the signature pad.
     */
    getDataUrl(type: DataUrlType, quality?: number): Promise<string>;
    /**
     * Clears the signature pad.
     */
    clear(): void;
    labelProps: T["element"];
    rootProps: T["element"];
    controlProps: T["element"];
    segmentProps: T["svg"];
    getSegmentPathProps(props: SegmentPathProps): T["path"];
    separatorProps: T["element"];
    clearTriggerProps: T["element"];
}

declare function connect<T extends PropTypes>(state: State, send: Send, normalize: NormalizeProps<T>): MachineApi<T>;

declare function machine(userContext: UserDefinedContext): _zag_js_core.Machine<MachineContext, MachineState, _zag_js_core.StateMachine.AnyEventObject>;

declare const props: ("disabled" | "dir" | "id" | "onDraw" | "onDrawEnd" | "drawing" | "readOnly" | "getRootNode")[];
declare const splitProps: <Props extends Partial<UserDefinedContext>>(props: Props) => [Partial<UserDefinedContext>, Omit<Props, "disabled" | "dir" | "id" | "onDraw" | "onDrawEnd" | "drawing" | "readOnly" | "getRootNode">];

export { type MachineApi as Api, type UserDefinedContext as Context, type DrawDetails, type DrawEndDetails, type SegmentPathProps, anatomy, connect, machine, props, splitProps };
